//-----------------------------------------------------------------------------
// Copyright  Micromega Corporation 2005-2008. All rights reserved.
//
// @file   fpu.h
// @target Microchip dsPIC C compiler
//
// Defines uM-FPU V3.1 opcodes, matrix operations and FFT operations.
// Functions prototypes for C calls to uM-FPU interface routines
//
// @author Cam Thompson, Micromega Corporation
// @version
//	August 26, 2008
//	- modified for dsPIC C compiler
//	July 2, 2008
//	- original version
//-----------------------------------------------------------------------------

#include "fops.h"				// define all opcodes

//-------------------- FPU status bits ----------------------------------------

#define STATUS_ZERO	0x01		// Zero status bit
#define STATUS_SIGN	0x02		// Sign status bit
#define STATUS_NAN	0x04		// NaN (Not-a-Number) status bit
#define STATUS_INF	0x08		// Infinity status bit

//-------------------- fpu_spi.c prototypes -----------------------------------

unsigned char fpu_reset(void);
void fpu_wait(void);

void fpu_write(unsigned char bval1);
void fpu_write2(unsigned char bval1, unsigned char bval2);
void fpu_write3(unsigned char bval1, unsigned char bval2, unsigned char bval3);
void fpu_write4(unsigned char bval1, unsigned char bval2, unsigned char bval3, unsigned char bval4);
void fpu_writeWord(int wval);
void fpu_writeFloat(float fval);
void fpu_writeLong(long lval);
void fpu_writeString(char *s);

unsigned char fpu_read(void);
unsigned char fpu_readByte(void);
int fpu_readWord(void);
float fpu_readFloat(void);
long fpu_readLong(void);
char *fpu_readString(char *s);
unsigned char fpu_readStatus(void);
void fpu_readDelay(void);

//-------------------- fpuPrint.c prototypes ----------------------------------

void print_version(void);
void print_long(char format);
void print_float(char format);
void print_fpuString(char opcode);
void print_CRLF(void);



