//=============================================================================
// Copyright  Micromega Corporation 2005-2008. All rights reserved.
//
// @file	template.c
// @target	Microchip MPLAB dsPIC C compiler
//
// This program provides an example of using the uM-FPU V3.1 floating point
// coprocessor with the dsPIC C compiler using an SPI interface. It shows
// the initial FPU reset sequence and prints the version number of the FPU.
// For an embedded application the print routines can be removed.
//
// @author	Cam Thompson, Micromega Corporation
// @version
//	August 29, 2008
//	- original version
//=============================================================================

// select device and set configuration bits
#include <p30f3012.h>
_FOSC(CSW_FSCM_OFF & FRC_PLL16);
_FWDT(WDT_OFF);
_FICD(ICS_PGD3);

// set clock frequency
#define FCY 29480000UL				// clock frequency: 29.48 MHz
#include <libpic30.h>

#include <stdio.h>
#include "fpu.h"

//-------------------- local prototypes ---------------------------------------

//-------------------- uM-FPU register definitions ----------------------------

//-------------------- main ---------------------------------------------------

int main(void) {

	// UART setup
	__C30_UART = 1;				// select UART1 for stdio
	U1BRG = 95;					// 19,200 baud @ 29.48 MHz
	U1MODEbits.ALTIO = 1;		// alternate I/O port
	U1MODEbits.UARTEN = 1;		// enable UART

	// print program name
	printf("\r\n\r\nTemplate\r\n");

	// Reset the uM-FPU
	if (fpu_reset() == SYNC_CHAR) {
		print_version();		// print version number
		print_CRLF();
	}
	else {
		printf("uM-FPU not detected");
		while(1) ;  			// stop if FPU reset fails
	}

//	Insert main application code here.
//	FPU instructions are sent using fpu_write functions.
//	e.g.
//		fpu_write4(SELECTA, 1, LOADPI, FSET0);

	printf("\r\nDone.\r\n");
	while(1) ;
}
